<template>
    <div class="app-container">
        <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
            <el-form-item label="体检号" prop="tjNumber">
                <el-input v-model="queryParams.tjNumber" placeholder="请输入体检号" style="width: 170px;"  clearable @keyup.enter.native="handleQuery" ref="inputName" @blur="handleQuery" />
            </el-form-item>
            <el-form-item label="客户名称" prop="printBy">
                <el-input v-model="queryParams.printBy" placeholder="客户名称" clearable style="width: 100px;"
                    @keyup.enter.native="handleQuery" />
            </el-form-item>
            <el-form-item label="打印时间" prop="printTime">
                <el-date-picker clearable v-model="queryParams.printTime" type="date" value-format="yyyy-MM-dd"
                    placeholder="请选择打印时间" style="width: 140px;">
                </el-date-picker>
            </el-form-item>
            <el-form-item label="打印状态" prop="printStatus">
        <el-select v-model="queryParams.printStatus" placeholder="打印状态" clearable style="width:110px">
          <el-option v-for="dict in dict.type.print_success_fail" :key="dict.value" :label="dict.label" :value="dict.value" />
        </el-select>
      </el-form-item>
            <el-form-item>
                <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
                <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
            </el-form-item>
        </el-form>

        <el-table v-loading="loading" :data="printList" @selection-change="handleSelectionChange" border style="width: 80%;">
            <el-table-column label="客户名称" align="center" prop="printBy" />
            <el-table-column label="体检号" align="center" prop="tjNumber" />
            <el-table-column label="打印操作员" align="center" prop="createBy" />
            <el-table-column label="打印时间" align="center" prop="printTime" width="180">
                <template slot-scope="scope">
                    <span>{{ parseTime(scope.row.printTime) }}</span>
                </template>
            </el-table-column>
            <el-table-column label="打印状态" align="center" prop="printStatus">
                <template slot-scope="scope">
                    <dict-tag :options="dict.type.print_success_fail" :value="scope.row.printStatus" />
                </template>
            </el-table-column>
        </el-table>

        <div class="pag">
      <div class="pag1">
        <pagination v-show="total > 0" :total="total" :page.sync="queryParams.pageNum" :limit.sync="queryParams.pageSize"
            @pagination="getList" />
      </div>
    </div>

      

    </div>
</template>

<script>
import {
    listPrint,
    getPrint,
    delPrint,
    addPrint,
    updatePrint
} from "@/api/hosp/print";
import { getInfo } from "@/api/login";
export default {
    name: "Print",
    dicts: ["print_success_fail",],
    data() {
        let checkPhoneNum = (rule, value, callback) => {
         console.log( value)
      let patter = new RegExp(/^1\s*[3456789]\s*(\d\s*){9}$/);
      if (value == "" && value == undefined && !value) {
        return callback('');
      }  else if(value != undefined && value != ""){
        return callback();
      }else if (!patter.test(value)) {
        return callback('');
      }
    };
        return {
            // 遮罩层
            loading: true,
            // 选中数组
            ids: [],
            // 非单个禁用
            single: true,
            // 非多个禁用
            multiple: true,
            // 显示搜索条件
            showSearch: true,
            // 总条数
            total: 0,
            // 打印记录表格数据
            printList: [],
            // 弹出层标题
            title: "",
            // 是否显示弹出层
            open: false,
            user: {},
            // 查询参数
            queryParams: {
                pageNum: 1,
                pageSize: 10,
                tjNumber: null,
                printBy: null,
                printTime: null,
                printStatus: null,
                createBy:null
            },
            // 表单参数
            form: {},
            // 表单校验
            rules: {
                deleted: [
                    {
                        required: true, validator: checkPhoneNum,  trigger: "blur"
                    }
                ]
            }
        };
    },
    created() {
        this.getList();
    },
    mounted() {
    this.$nextTick(() => {
      this.$refs.inputName.focus();
    });
  },
    methods: {
        /** 查询打印记录列表 */
        getList() {
            this.loading = true;
            getInfo().then((response) => {
                this.user = response.user
            });
            listPrint(this.queryParams).then(response => {
                this.printList = response.rows;
                this.printList.forEach(item => {
                    if (item.createBy === this.user.userId) {
                        item.createBy = this.user.nickName
                    }
                })
                this.total = response.total;
                this.loading = false;
            });
        },
        // 取消按钮
        cancel() {
            this.open = false;
            this.reset();
        },
        // 表单重置
        reset() {
            this.form = {
                id: null,
                tjNumber: null,
                printBy: null,
                printTime: null,
                printStatus: null,
                createTime: null,
                createBy: null,
                updateTime: null,
                updateBy: null,
                deleted: null
            };
            this.resetForm("form");
        },
        /** 搜索按钮操作 */
        handleQuery() {
            this.queryParams.pageNum = 1;
            this.getList();
        },
        /** 重置按钮操作 */
        resetQuery() {
            this.resetForm("queryForm");
            this.handleQuery();
        },
        // 多选框选中数据
        handleSelectionChange(selection) {
            this.ids = selection.map(item => item.id)
            this.single = selection.length !== 1
            this.multiple = !selection.length
        },
        /** 新增按钮操作 */
        handleAdd() {
            this.reset();
            this.open = true;
            this.title = "添加打印记录";
        },
        /** 修改按钮操作 */
        handleUpdate(row) {
            this.reset();
            const id = row.id || this.ids
            getPrint(id).then(response => {
                this.form = response.data;
                this.open = true;
                this.title = "修改打印记录";
            });
        },


    }

};
</script>

<style>
.pag {
  width: 100%;
  display: flex;
  justify-content: center;
}

.pag1 {
  width: 30%;
}
</style>
